changeset 22760:e080fa4636c7

(Info-read-node-name-1, Info-read-node-name): Rename completion-table to Info-read-node-completion-table. (Info-read-node-completion-table): Add defvar.
author Richard M. Stallman <rms@gnu.org>
date Wed, 15 Jul 1998 00:07:49 +0000
parents be3e1a724828
children ad14990a5efc
files lisp/info.el
diffstat 1 files changed, 7 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/info.el	Tue Jul 14 23:42:21 1998 +0000
+++ b/lisp/info.el	Wed Jul 15 00:07:49 1998 +0000
@@ -773,27 +773,29 @@
     (Info-find-node (if (equal filename "") nil filename)
 		    (if (equal nodename "") "Top" nodename))))
 
+(defvar Info-read-node-completion-table)
+
 ;; This function is used as the "completion table" while reading a node name.
 ;; It does completion using the alist in completion-table
 ;; unless STRING starts with an open-paren.
 (defun Info-read-node-name-1 (string predicate code)
   (let ((no-completion (and (> (length string) 0) (eq (aref string 0) ?\())))
     (cond ((eq code nil)
 	   (if no-completion
 	       string
-	     (try-completion string completion-table predicate)))
+	     (try-completion string Info-read-node-completion-table predicate)))
 	  ((eq code t)
 	   (if no-completion
 	       nil
-	     (all-completions string completion-table predicate)))
+	     (all-completions string Info-read-node-completion-table predicate)))
 	  ((eq code 'lambda)
 	   (if no-completion
 	       t
-	     (assoc string completion-table))))))
+	     (assoc string Info-read-node-completion-table))))))
 
 (defun Info-read-node-name (prompt &optional default)
   (let* ((completion-ignore-case t)
-	 (completion-table (Info-build-node-completions))
+	 (Info-read-node-completion-table (Info-build-node-completions))
 	 (nodename (completing-read prompt 'Info-read-node-name-1 nil t)))
     (if (equal nodename "")
 	(or default
@@ -773,27 +773,29 @@
 ;; This function is used as the "completion table" while reading a node name.
-;; It does completion using the alist in completion-table
+;; It does completion using the alist in Info-read-node-completion-table
 ;; unless STRING starts with an open-paren.
 (defun Info-read-node-name-1 (string predicate code)